@@ -5,7 +5,7 @@
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
-#define g_marshal_value_peek_char(v)     g_value_get_char (v)
+#define g_marshal_value_peek_char(v)     g_value_get_schar (v)
 #define g_marshal_value_peek_uchar(v)    g_value_get_uchar (v)
 #define g_marshal_value_peek_int(v)      g_value_get_int (v)
 #define g_marshal_value_peek_uint(v)     g_value_get_uint (v)
@@ -64,9 +64,9 @@ tumbler_marshal_VOID__STRING_INT_STRING (GClosure     *closure,
                                                         gint         arg_2,
                                                         gpointer     arg_3,
                                                         gpointer     data2);
-  register GMarshalFunc_VOID__STRING_INT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_INT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -104,9 +104,9 @@ tumbler_marshal_VOID__UINT_STRING_INT_STRING (GClosure     *closure,
                                                              gint         arg_3,
                                                              gpointer     arg_4,
                                                              gpointer     data2);
-  register GMarshalFunc_VOID__UINT_STRING_INT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_STRING_INT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -146,9 +146,9 @@ tumbler_marshal_VOID__UINT_BOXED_INT_STRING_STRING (GClosure     *closure,
                                                                    gpointer     arg_4,
                                                                    gpointer     arg_5,
                                                                    gpointer     data2);
-  register GMarshalFunc_VOID__UINT_BOXED_INT_STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_BOXED_INT_STRING_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 6);
 
@@ -189,9 +189,9 @@ tumbler_marshal_VOID__UINT_BOXED_STRING (GClosure     *closure,
                                                         gpointer     arg_2,
                                                         gpointer     arg_3,
                                                         gpointer     data2);
-  register GMarshalFunc_VOID__UINT_BOXED_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_BOXED_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -227,9 +227,9 @@ tumbler_marshal_VOID__UINT_STRING (GClosure     *closure,
                                                   guint        arg_1,
                                                   gpointer     arg_2,
                                                   gpointer     data2);
-  register GMarshalFunc_VOID__UINT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -266,9 +266,9 @@ tumbler_marshal_VOID__UINT_POINTER_INT_STRING (GClosure     *closure,
                                                               gint         arg_3,
                                                               gpointer     arg_4,
                                                               gpointer     data2);
-  register GMarshalFunc_VOID__UINT_POINTER_INT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_POINTER_INT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
